@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import abc
 import logging
 import subprocess
@@ -17,9 +19,10 @@ else:
     ABC = abc.ABC
 
 _logger = logging.getLogger("install_addons")
-handler = logging.StreamHandler()
-_logger.addHandler(handler)
 _logger.setLevel(logging.INFO)
+if not _logger.handlers:
+    handler = logging.StreamHandler()
+    _logger.addHandler(handler)
 
 
 class AddonsRegistry(object):
@@ -330,7 +333,7 @@ class LocalOdooAddons(AddonsSuffix):
         super(LocalOdooAddons, self).__init__("ADDONS_LOCAL", base_key)
         self.BASE_PATH = self.create_key("BASE_PATH", default="/")
 
-    def extract(self, env_vars):  # type: (Dict[str, str]) -> Result
+    def extract(self, env_vars):  # type: (Dict[str, str]) -> LocalOdooAddons.Result
         res = self.to_dict(env_vars)
         return LocalOdooAddons.Result(
             name=self.NAME.full_key,
